#include "pagewidget.h"

#include <poppler-qt4.h>
#include <QApplication>
#include <QDesktopWidget>
#include <QPainter>

PageWidget::PageWidget(QWidget *parent) :
    QWidget(parent),
    mPageNumber(0),
    mDocPath("")
{
}

void PageWidget::setDocumentPath(const QString &path)
{
    mDocPath = path;
}

void PageWidget::displayPage(int pageNumber)
{
    mPageNumber = pageNumber;

    update();
}

void PageWidget::displayPrevPage()
{
    mPageNumber--;
    update();
}

void PageWidget::displayNextPage()
{
    mPageNumber++;
    update();
}

void PageWidget::paintEvent(QPaintEvent *)
{
    if(mDocPath.isEmpty()) return;

    QPainter p;
    p.begin(this);

    Poppler::Document *doc = Poppler::Document::load(mDocPath);
    doc->setRenderBackend(Poppler::Document::ArthurBackend);
    doc->setRenderHint(Poppler::Document::Antialiasing);
    doc->setRenderHint(Poppler::Document::TextAntialiasing);

    Poppler::Page* page = doc->page(mPageNumber);
    page->renderToPainter(&p);

    p.end();


    delete page;
    delete doc;
}
